# Curvey API

- [`curvey.curve`](curve.md)
    - The main curve class

- [`curvey.curves`](curves.md)
    - A container of curves

- [`curvey.shape_structure_data`](shape_structure_dataset.md)
    - Interface to the 2D Shape Structure Dataset

- [`curvey.flow`](flow.md)
    - Curve shortening flow, Willmore flow, etc.

- [`curvey.blend`](blend.md)
    - Linear and curvature blending for shape interpolation
